==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/devtestlab/kotlin/inputs/LabAnnouncementPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devtestlab.kotlin.inputs

import com.pulumi.azurenative.devtestlab.inputs.LabAnnouncementPropertiesArgs.builder
import com.pulumi.azurenative.devtestlab.kotlin.enums.EnableStatus
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties of a lab's announcement banner
 * @property enabled Is the lab announcement active/enabled at this time?
 * @property expirationDate The time at which the announcement expires (null for never)
 * @property expired Has this announcement expired?
 * @property markdown The markdown text (if any) that this lab displays in the UI. If left empty/null, nothing will be shown.
 * @property title The plain text title for the lab announcement
 */
public data class LabAnnouncementPropertiesArgs(
    public val enabled: Output<Either<String, EnableStatus>>? = null,
    public val expirationDate: Output<String>? = null,
    public val expired: Output<Boolean>? = null,
    public val markdown: Output<String>? = null,
    public val title: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.devtestlab.inputs.LabAnnouncementPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.devtestlab.inputs.LabAnnouncementPropertiesArgs =
        com.pulumi.azurenative.devtestlab.inputs.LabAnnouncementPropertiesArgs.builder()
            .enabled(
                enabled?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .expirationDate(expirationDate?.applyValue({ args0 -> args0 }))
            .expired(expired?.applyValue({ args0 -> args0 }))
            .markdown(markdown?.applyValue({ args0 -> args0 }))
            .title(title?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LabAnnouncementPropertiesArgs].
 */
@PulumiTagMarker
public class LabAnnouncementPropertiesArgsBuilder internal constructor() {
    private var enabled: Output<Either<String, EnableStatus>>? = null

    private var expirationDate: Output<String>? = null

    private var expired: Output<Boolean>? = null

    private var markdown: Output<String>? = null

    private var title: Output<String>? = null

    /**
     * @param value Is the lab announcement active/enabled at this time?
     */
    @JvmName("vgkqiqdkucbwopuk")
    public suspend fun enabled(`value`: Output<Either<String, EnableStatus>>) {
        this.enabled = value
    }

    /**
     * @param value The time at which the announcement expires (null for never)
     */
    @JvmName("rbhrnuogxyjjbwtw")
    public suspend fun expirationDate(`value`: Output<String>) {
        this.expirationDate = value
    }

    /**
     * @param value Has this announcement expired?
     */
    @JvmName("pcjvutbnnwxvjvpv")
    public suspend fun expired(`value`: Output<Boolean>) {
        this.expired = value
    }

    /**
     * @param value The markdown text (if any) that this lab displays in the UI. If left empty/null, nothing will be shown.
     */
    @JvmName("defmhojfnspvptvp")
    public suspend fun markdown(`value`: Output<String>) {
        this.markdown = value
    }

    /**
     * @param value The plain text title for the lab announcement
     */
    @JvmName("gdlwkeunywojbket")
    public suspend fun title(`value`: Output<String>) {
        this.title = value
    }

    /**
     * @param value Is the lab announcement active/enabled at this time?
     */
    @JvmName("jkmememkxtpfhsid")
    public suspend fun enabled(`value`: Either<String, EnableStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Is the lab announcement active/enabled at this time?
     */
    @JvmName("jtmqrhlupkoeieus")
    public fun enabled(`value`: String) {
        val toBeMapped = Either.ofLeft<String, EnableStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Is the lab announcement active/enabled at this time?
     */
    @JvmName("wuqyxfptofjtedhe")
    public fun enabled(`value`: EnableStatus) {
        val toBeMapped = Either.ofRight<String, EnableStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value The time at which the announcement expires (null for never)
     */
    @JvmName("mwtojydwkgnfkedw")
    public suspend fun expirationDate(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expirationDate = mapped
    }

    /**
     * @param value Has this announcement expired?
     */
    @JvmName("ibwwlcvyogmmguhc")
    public suspend fun expired(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expired = mapped
    }

    /**
     * @param value The markdown text (if any) that this lab displays in the UI. If left empty/null, nothing will be shown.
     */
    @JvmName("sgxmkpfvpkkgiwih")
    public suspend fun markdown(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.markdown = mapped
    }

    /**
     * @param value The plain text title for the lab announcement
     */
    @JvmName("rwpcvkaasxfmlthq")
    public suspend fun title(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.title = mapped
    }

    internal fun build(): LabAnnouncementPropertiesArgs = LabAnnouncementPropertiesArgs(
        enabled = enabled,
        expirationDate = expirationDate,
        expired = expired,
        markdown = markdown,
        title = title,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/devtestlab/kotlin/inputs/LabAnnouncementPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devtestlab.kotlin.inputs

import com.pulumi.azurenative.devtestlab.inputs.LabAnnouncementPropertiesArgs.builder
import com.pulumi.azurenative.devtestlab.kotlin.enums.EnableStatus
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties of a lab's announcement banner
 * @property enabled Is the lab announcement active/enabled at this time?
 * @property expirationDate The time at which the announcement expires (null for never)
 * @property expired Has this announcement expired?
 * @property markdown The markdown text (if any) that this lab displays in the UI. If left empty/null, nothing will be shown.
 * @property title The plain text title for the lab announcement
 */
public data class LabAnnouncementPropertiesArgs(
    public val enabled: Output<Either<String, EnableStatus>>? = null,
    public val expirationDate: Output<String>? = null,
    public val expired: Output<Boolean>? = null,
    public val markdown: Output<String>? = null,
    public val title: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.devtestlab.inputs.LabAnnouncementPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.devtestlab.inputs.LabAnnouncementPropertiesArgs =
        com.pulumi.azurenative.devtestlab.inputs.LabAnnouncementPropertiesArgs.builder()
            .enabled(
                enabled?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .expirationDate(expirationDate?.applyValue({ args0 -> args0 }))
            .expired(expired?.applyValue({ args0 -> args0 }))
            .markdown(markdown?.applyValue({ args0 -> args0 }))
            .title(title?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LabAnnouncementPropertiesArgs].
 */
@PulumiTagMarker
public class LabAnnouncementPropertiesArgsBuilder internal constructor() {
    private var enabled: Output<Either<String, EnableStatus>>? = null

    private var expirationDate: Output<String>? = null

    private var expired: Output<Boolean>? = null

    private var markdown: Output<String>? = null

    private var title: Output<String>? = null

    /**
     * @param value Is the lab announcement active/enabled at this time?
     */
    @JvmName("pkrbykvcnjritanv")
    public suspend fun enabled(`value`: Output<Either<String, EnableStatus>>) {
        this.enabled = value
    }

    /**
     * @param value The time at which the announcement expires (null for never)
     */
    @JvmName("hcrhptqvhelncnat")
    public suspend fun expirationDate(`value`: Output<String>) {
        this.expirationDate = value
    }

    /**
     * @param value Has this announcement expired?
     */
    @JvmName("dwjafwcooxvgnqnh")
    public suspend fun expired(`value`: Output<Boolean>) {
        this.expired = value
    }

    /**
     * @param value The markdown text (if any) that this lab displays in the UI. If left empty/null, nothing will be shown.
     */
    @JvmName("pfsaqjplpptpvlwu")
    public suspend fun markdown(`value`: Output<String>) {
        this.markdown = value
    }

    /**
     * @param value The plain text title for the lab announcement
     */
    @JvmName("yoyhbseaxvmunmyi")
    public suspend fun title(`value`: Output<String>) {
        this.title = value
    }

    /**
     * @param value Is the lab announcement active/enabled at this time?
     */
    @JvmName("lgjrohdvqsqwdasi")
    public suspend fun enabled(`value`: Either<String, EnableStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Is the lab announcement active/enabled at this time?
     */
    @JvmName("kpxxyscvimxxjooh")
    public fun enabled(`value`: String) {
        val toBeMapped = Either.ofLeft<String, EnableStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Is the lab announcement active/enabled at this time?
     */
    @JvmName("cthquofbsknpgptl")
    public fun enabled(`value`: EnableStatus) {
        val toBeMapped = Either.ofRight<String, EnableStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value The time at which the announcement expires (null for never)
     */
    @JvmName("latwaxdpuxdyqiri")
    public suspend fun expirationDate(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expirationDate = mapped
    }

    /**
     * @param value Has this announcement expired?
     */
    @JvmName("bdqtfjdybfrdfrnw")
    public suspend fun expired(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expired = mapped
    }

    /**
     * @param value The markdown text (if any) that this lab displays in the UI. If left empty/null, nothing will be shown.
     */
    @JvmName("wgwcwfyhfaylebjv")
    public suspend fun markdown(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.markdown = mapped
    }

    /**
     * @param value The plain text title for the lab announcement
     */
    @JvmName("jrafsntrcxheojdl")
    public suspend fun title(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.title = mapped
    }

    internal fun build(): LabAnnouncementPropertiesArgs = LabAnnouncementPropertiesArgs(
        enabled = enabled,
        expirationDate = expirationDate,
        expired = expired,
        markdown = markdown,
        title = title,
    )
}
